"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const highlight_tree_sitter_1 = require("highlight-tree-sitter");
const Parser = require("tree-sitter");
const Javascript = require("tree-sitter-javascript");
const CSON = require("cson");
const JavascriptGrammar = CSON.requireFile(require.resolve('language-javascript/grammars/tree-sitter-javascript.cson'));
const parser = new Parser();
parser.setLanguage(Javascript);
const text = `
function foo() {
  return 1;
}`;
const tree = parser.parse(text);
console.log(`
======================================================================
Parsing text:
======================================================================
${text}
`);
const partial = highlight_tree_sitter_1.partialSexp(tree);
console.log(`
======================================================================
Partial Tree:
- only named node types are shown
- (no text)
======================================================================

${highlight_tree_sitter_1.printSexp(partial)}
`);
const full = highlight_tree_sitter_1.fullSexp(text, tree);
console.log(`
======================================================================
Full Tree:
- _root = top level node to catch extra whitespace
- _anon = unnamed node
- (all text is shown as quoted forms)
======================================================================

${highlight_tree_sitter_1.printSexp(full)}
`);
const highlight = highlight_tree_sitter_1.highlightSexpFromScopes(full, JavascriptGrammar.scopes);
console.log(JSON.stringify(highlight, null, 2));
console.log(`
======================================================================
Highlighted Tree:
======================================================================

CLASSES APPENDED TO NODE NAMES:
${highlight_tree_sitter_1.printSexp(highlight.renamedSexp)}

NODES WITHOUT CLASSES FLATTENED:
${highlight_tree_sitter_1.printSexp(highlight.sexp)}
`);
console.log(`
======================================================================
HTML:
======================================================================
${highlight.html}
`);
